Skip to contents

Converts Fisher's Z back into the scale of a correlation coefficient (r). Fisher's Z is the variance-stabilizing transformation of a correlation; many authors call it the z-prime transform and write the transformed value as z'. The capital Z is meaningful: Fisher's Z is not a z-score (it is not a standardized variate, that is, an observation centered and divided by a standard deviation). This function applies the inverse transform \(r = \mathrm{tanh}(Z)\) to return to the scale of a correlation coefficient.

Usage

convert_Z_r(Z)

Arguments

Z

Fisher's Z (the variance-stabilizing transform of a correlation, which many authors call z')

Value

A 1-row data.frame with columns term and value. The term is "r_from_Z" and value is the correlation coefficient corresponding to the supplied Fisher's Z. The inverse direction is convert_r_Z.

Details

This function is typically used in the context of forming a confidence interval for a population correlation coefficient. Note that, in that situation, the two variables are assumed to follow a bivariate normal distribution (e.g., Hays, 1994).

References

Kelley, K. (2007). Confidence intervals for standardized effect sizes: Theory, application, and implementation. Journal of Statistical Software, 20(8), 1–24. doi:10.18637/jss.v020.i08

Hays, W. L. (1994). Statistics (5th ed.). Fort Worth, TX: Harcourt Brace College Publishers.

Author

Ken Kelley kkelley@nd.edu

Examples

# From Hays (1994, pp. 649--650)
convert_Z_r(0.3654438)
#>  term     value
#>  r_from_Z 0.35