Computes a confidence interval for a population regression
coefficient in its raw (unstandardized) metric, by the standard
t-based approach or the noncentral t approach. A thin
convenience wrapper around ci_reg_coef, which is the
general engine; for the standardized coefficient use
ci_src.
Usage
ci_rc(
b_j,
SE_b_j = NULL,
s_Y = NULL,
s_X = NULL,
N,
p,
R2_Y_X = NULL,
R2_j_X_without_j = NULL,
conf_level = 0.95,
R2_Y_X_without_j = NULL,
t_value = NULL,
alpha_lower = NULL,
alpha_upper = NULL,
noncentral = FALSE,
...
)Arguments
- b_j
Value of the regression coefficient for the jth predictor variable
- SE_b_j
Standard error for the jth predictor variable
- s_Y
Standard deviation of Y, the dependent variable
- s_X
Standard deviation of X, the predictor variable of interest
- N
Sample size
- p
The number of predictors
- R2_Y_X
The squared multiple correlation coefficient predicting Y from the p predictor variables
- R2_j_X_without_j
The squared multiple correlation coefficient predicting the jth predictor variable (i.e., the predictor of interest) from the remaining p-1 predictor variables
- conf_level
Desired level of confidence for the computed interval (i.e., 1 - the Type I error rate)
- R2_Y_X_without_j
The squared multiple correlation coefficient predicting Y from the p-1 predictor variable with the jth predictor of interest excluded
- t_value
The t-value evaluating the null hypothesis that the population regression coefficient for the jth predictor equals zero
- alpha_lower
The Type I error rate for the lower confidence interval limit
- alpha_upper
The Type I error rate for the upper confidence interval limit
- noncentral
TRUEorFALSEstatement specifying whether or not the noncentral approach to confidence intervals should be used- ...
Optional additional specifications for nested functions
Value
A 2-row data.frame with columns term, value,
prob_less, and prob_greater. The term values are
"lower_limit" and "upper_limit", and value holds
the confidence limits on the regression coefficient in its raw metric.
The prob_less and prob_greater columns report the tail
probabilities below and above each limit; when the noncentral t
approach is used they are the achieved tail probabilities. Unlike
ci_src and ci_reg_coef, which place the
point estimate between its limits as a third row, ci_rc returns
the two limits only.
Details
Returns the confidence limits for the regression coefficient of interest from the standard approach to confidence interval formation or from the noncentral approach to confidence interval formation using the noncentral t-distribution.
Note
Not all of the values need to be specified, only those that contain all of the necessary information in order to compute the confidence interval (options are thus given for the values that need to be specified).
References
Kelley, K. (2007). Confidence intervals for standardized effect sizes: Theory, application, and implementation. Journal of Statistical Software, 20(8), 1–24. doi:10.18637/jss.v020.i08
Kelley, K., & Maxwell, S. E. (2003). Sample size for multiple regression: Obtaining regression coefficients that are accurate, not simply significant. Psychological Methods, 8(3), 305–321. doi:10.1037/1082-989X.8.3.305
Kelley, K., & Maxwell, S. E. (2008). Sample size planning with applications to multiple regression: Power and accuracy for omnibus and targeted effects. In P. Alasuutari, L. Bickman, & J. Brannen (Eds.), The Sage handbook of social research methods (pp. 166–192). Sage.
Maxwell, S. E., Delaney, H. D., & Kelley, K. (2027). Designing experiments and analyzing data: A model comparison perspective (4th ed.). Routledge. (See Chapter 4 on individual comparisons of means and Chapter 6 on trend analysis.)
Smithson, M. (2003). Confidence intervals. Thousand Oaks, CA: Sage Publications.
Steiger, J. H. (2004). Beyond the F Test: Effect size confidence intervals and tests of close fit in the Analysis of Variance and Contrast Analysis. Psychological Methods, 9(2), 164–182. doi:10.1037/1082-989X.9.2.164
See also
ss_aipe_reg_coef, conf_limits_nct, ci_reg_coef, ci_src
Other confidence intervals for effect sizes:
ci_R2(),
ci_c(),
ci_c_ancova(),
ci_c_ancova_bp(),
ci_correlation,
ci_cv(),
ci_eta_squared(),
ci_eta_squared_generalized(),
ci_eta_squared_partial(),
ci_mahalanobis(),
ci_omega_squared(),
ci_pvaf(),
ci_reg_coef(),
ci_rmsea(),
ci_sc(),
ci_sc_ancova(),
ci_sm(),
ci_smd(),
ci_smd_c(),
ci_snr(),
ci_src(),
ci_srsnr(),
contrast_adjusted(),
plot_smd()
Author
Ken Kelley kkelley@nd.edu