Convert a Correlation Coefficient (r) Into the Scale of Fisher's Z
Source:R/convert_r_Z.R
convert_r_Z.RdThis function converts a correlation coefficient into the scale of Fisher's Z, the variance-stabilizing transformation of a correlation. Many authors call this map the z-prime transform and write the transformed value as z'. The capital Z is meaningful: Fisher's Z is not a z-score (it is not a standardized variate, that is, an observation centered and divided by a standard deviation). It is the transform \(Z = \mathrm{atanh}(r)\) of a correlation coefficient, applied because the sampling distribution of Z is approximately normal with a variance that does not depend on the population correlation, which makes Z convenient for forming confidence intervals.
Value
A 1-row data.frame with columns term and
value. The term is "Z_from_r" and value
is Fisher's Z corresponding to the supplied correlation
coefficient. The inverse direction is convert_Z_r.
Details
This function is typically used in the context of forming a confidence interval for a population correlation coefficient. Note that, in that situation, the two variables are assumed to follow a bivariate normal distribution (e.g., Hays, 1994).
References
Kelley, K. (2007). Confidence intervals for standardized effect sizes: Theory, application, and implementation. Journal of Statistical Software, 20(8), 1–24. doi:10.18637/jss.v020.i08
Hays, W. L. (1994). Statistics (5th ed.). Fort Worth, TX: Harcourt Brace College Publishers.
See also
Other parameterization conversions:
convert_F_chisq(),
convert_R2,
convert_Z_r(),
convert_cor_cov(),
convert_d_or(),
convert_d_r(),
convert_t_smd,
convert_z_normal()
Author
Ken Kelley kkelley@nd.edu