Functions useful for converting a standardized mean difference to a noncentrality parameter, and vice versa.
Value
Each function returns a 1-row data.frame with columns
term and value. The term entry identifies the
conversion ("delta_lambda" or "lambda_delta") and
value is the converted scalar. The two functions are exact
inverses given the per-group sample sizes
n_1 and n_2.
Details
Although lambda is the population noncentral value, an estimate of it is the observed value of a
t-statistic. Likewise, delta can be estimated as the observed standardized mean difference. Thus, the observed
standardized mean difference can be converted to the observed t-value. These functions are especially helpful in the
context of forming confidence intervals for the population standardized mean difference.
References
Kelley, K. (2007). Confidence intervals for standardized effect sizes: Theory, application, and implementation. Journal of Statistical Software, 20(8), 1–24. doi:10.18637/jss.v020.i08
See also
Other parameterization conversions:
convert_F_chisq(),
convert_R2,
convert_Z_r(),
convert_cor_cov(),
convert_d_or(),
convert_d_r(),
convert_r_Z(),
convert_z_normal()
Author
Ken Kelley kkelley@nd.edu